==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/script/pokladnikniha.js <==
/**
 * Created by pavel.rudol on 24.3.2016.
 */


function showDokumentPokladniKnihyDialog(id) {

    var dokumentPokladniKnihyResult = function(result) {
        processDokumentResult(result, '?menuid=pokladnikniha&action=zaznam&record=' + id);
    };

    ronPortal.showDokumentDialog(dokumentPokladniKnihyResult);
    return false;
}

ron.PokladniKniha = { };

ron.PokladniKniha.DataTypuPolozky = function() {
    this.typ_polozky = '';
    this.povolit_castka_bez_dph = 0;
    this.povolit_castka_dph = 0;
    this.povolit_castka = 0;
};

ron.PokladniKniha = {
    hromadneSchvaleni : {
        zobrazHromadne : function () {
            window.location = window.location + '&schvalovani=1';
        },

        init : function (dataSchvalovani) {

            /**
             * oznaci radek, pokud je v nem nejaka zmena
             * @param index
             */
            var oznacRadekPoklK = function (index) {
                var selected = false;

                if (dataSchvalovani.items[index].pravo_1) {
                    if ($("#Schvaleni_" + dataSchvalovani.items[index].id + "_1").prop("checked") != !!dataSchvalovani.items[index].schvaleno_1) selected = true;
                }

                if (!selected && dataSchvalovani.items[index].pravo_2) {
                    if ($("#Schvaleni_" + dataSchvalovani.items[index].id + "_2").prop("checked") != !!dataSchvalovani.items[index].schvaleno_2) selected = true;
                }

                if (!selected && dataSchvalovani.items[index].pravo_3) {
                    if ($("#Schvaleni_" + dataSchvalovani.items[index].id + "_3").checked != !!dataSchvalovani.items[index].schvaleno_3) selected = true;
                }


                $("#poklk_row_" + dataSchvalovani.items[index].id).toggleClass("browserselectedrow", selected);
            };


            var schvaleniCheckboxClick = function () {
                var index = $(this).data("ronschvalenipoklk_index");
                if (index === undefined) return;

                oznacRadekPoklK(index);
            };


            /**
             * @param {int} value
             * @param {string} uroven
             */
            var oznacVsechnyZaznamy = function (value, uroven) {
                for (var i = 0; i < dataSchvalovani.items.length; i++) {
                    var jePravo = false;
                    var checkboxId = null;

                    var originalValue = null;

                    switch (uroven) {
                        case '1' :
                            jePravo = dataSchvalovani.items[i].pravo_1;
                            checkboxId = 'Schvaleni_' + dataSchvalovani.items[i].id + '_1';
                            originalValue = dataSchvalovani.items[i].schvaleno_1;
                            break;

                        case '2' :
                            jePravo = dataSchvalovani.items[i].pravo_2;
                            checkboxId = 'Schvaleni_' + dataSchvalovani.items[i].id + '_2';
                            originalValue = dataSchvalovani.items[i].schvaleno_2;
                            break;

                        case '3' :
                            jePravo = dataSchvalovani.items[i].pravo_3;
                            checkboxId = 'Schvaleni_' + dataSchvalovani.items[i].id + '_3';
                            originalValue = dataSchvalovani.items[i].schvaleno_3;
                            break;
                    }

                    if (jePravo && checkboxId) {
                        var newvalue = !!( value < 0 ? originalValue : value);
                        if (document.getElementById(checkboxId).checked != newvalue) {
                            document.getElementById(checkboxId).checked = newvalue;
                            oznacRadekPoklK(i);
                        }
                    }
                }
            };


            var schvaleniPoklKMenu = function ($sender, uroven) {
                var $menu = $("#schvaleniPoklKMenu");

                $menu
                    .off("click", "li")
                    .on("click", "li", function () {
                        oznacVsechnyZaznamy($(this).data("ron-hodnotaschvaleni"), uroven);
                    });

                ron.showPopupMenu($menu, {attachToElement: $sender});

                return false; // stop event propagation
            };


            $("#schvaleniPKMenu_1")
                .on("click", function () {
                    schvaleniPoklKMenu($(this), "1");
                    return false;
                });

            $("#schvaleniPKMenu_2")
                .on("click", function () {
                    schvaleniPoklKMenu($(this), "2");
                    return false;
                });

            $("#schvaleniPKMenu_3")
                .on("click", function () {
                    schvaleniPoklKMenu($(this), "3");
                    return false;
                });

            $("#schvaleni_ALL_1")
                .on("click", function () {
                    oznacVsechnyZaznamy($(this).prop("checked"), "1");
                });

            $("#schvaleni_ALL_2")
                .on("click", function () {
                    oznacVsechnyZaznamy($(this).prop("checked"), "2");
                });

            $("#schvaleni_ALL_3")
                .on("click", function () {
                    oznacVsechnyZaznamy($(this).prop("checked"), "3");
                });

            $("#seznampokladniknihy")
                .on("click", "input", schvaleniCheckboxClick);

            $("#stornoHromadneSchvaleniPoklK")
                .on("click", function () {
                    //window.location = '?menuid=pokladnikniha';
                    window.location = $(this).data('browserlink');
                });

            $("#provestHromadneSchvaleniPoklK")
                .on("click", function () {
                    ron.showWorkingInfo();
                    this.form.submit();
                });


        }
    },

    formular : {
        /**
         * @param dataTypyPolozek ron.PokladniKniha.DataTypuPolozky[]
         */
        init : function (dataTypyPolozek) {
            var typPolozky = $('#typ_polozky');

            var zobrazeniCastkyDleTypu = function (data) {
                var value = '';

                //pro pripad, kdy je funkce volana po zmene comboboxu (tzn. jako parametr se predava event object,
                // hodnota se pak nacte z odeslaneho objektu]
                if (typeof data == 'object') {
                    value = $(this).val().toString();
                }
                //pokud se funkce vola pri incicializaci, predava se primo hodnota - kod typu polozky
                else {
                    value = data;
                }

                //v poli zobrazenych typu polozek pokladni knihy se vyhleda aktualne vybrany typ a podle toho se nastavi viditelnost
                for (var i = 0; i < dataTypyPolozek.items.length; i++) {
                    if (dataTypyPolozek.items[i].typ_polozky.toLowerCase() === value.toLowerCase()) {
                        $('#row_castka_bez_dph').toggle(dataTypyPolozek.items[i].povolit_castka_bez_dph === 1);
                        $('#row_castka_dph').toggle(dataTypyPolozek.items[i].povolit_castka_dph === 1);

                        $('#row_castka').toggle(dataTypyPolozek.items[i].povolit_castka === 1);
                        if (dataTypyPolozek.items[i].povolit_castka !== 1) {
                            $('#poklkniha_castka_noedit').removeClass('hidden');
                        } else {
                            $('#poklkniha_castka_noedit').addClass('hidden');
                        }
                    }
                }
            };

            var prepocetCastky = function () {
                var result = Number();

                var $inputBezDPH = $('#row_castka_bez_dph').find('input');
                var $inputDPH = $('#row_castka_dph').find('input');

                result = ron.utils.stringToFloat($inputBezDPH.val()) + ron.utils.stringToFloat($inputDPH.val());

                //zapis souctu castky bez DPH a castky DPH do textove castky
                $('#castka_pokladni_knihy').text(result);
                //pokud je viditelne jedno z poli pro castku bez DPH nebo castku DPH, zapise se soucet do inputu pro castku
                if ($inputBezDPH.length > 0 || $inputDPH.length > 0) {
                    $('#row_castka').find('input[name="castka"]').val(result);
                }
            };

            zobrazeniCastkyDleTypu($(typPolozky).find('select').val().toString());
            prepocetCastky();

            $(typPolozky).on('change','select', zobrazeniCastkyDleTypu);

            $('#row_castka_bez_dph').on('change', 'input', prepocetCastky);
            $('#row_castka_dph').on('change', 'input', prepocetCastky);
        }
    },

    detail : {
        vraceniZaznamuPokladniKnihyClick : function(sender) {
            $("#vracenipokladniknihy").show();
            $(this).hide();

            return false; // puvodni odkaz se nepouzije
        }
    }
};

$(function() {
    $(document.body)
        .on("click", ".vraceni_pokladni_knihy_link", ron.PokladniKniha.detail.vraceniZaznamuPokladniKnihyClick)
        .on('click', '#poklk_hromadneschvalovani', ron.PokladniKniha.hromadneSchvaleni.zobrazHromadne)
});

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/script/pokladnikniha.js <==


ron.PokladniKniha = { };

ron.PokladniKniha.DataTypuPolozky = function() {
    this.typ_polozky = '';
    this.povolit_castka_bez_dph = 0;
    this.povolit_castka_dph = 0;
    this.povolit_castka = 0;
};

ron.PokladniKniha = {
    hromadneSchvaleni : {
        zobrazHromadne : function () {
            window.location = window.location + '&schvalovani=1';
        },

        init : function (dataSchvalovani) {
            var oznacRadekPoklK = function (index) {
                var selected = false;

                if (dataSchvalovani.items[index].pravo_1) {
                    if ($("#Schvaleni_" + dataSchvalovani.items[index].id + "_1").prop("checked") !== !!dataSchvalovani.items[index].schvaleno_1) selected = true;
                }

                if (!selected && dataSchvalovani.items[index].pravo_2) {
                    if ($("#Schvaleni_" + dataSchvalovani.items[index].id + "_2").prop("checked") !== !!dataSchvalovani.items[index].schvaleno_2) selected = true;
                }

                if (!selected && dataSchvalovani.items[index].pravo_3) {
                    if ($("#Schvaleni_" + dataSchvalovani.items[index].id + "_3").prop("checked") !== !!dataSchvalovani.items[index].schvaleno_3) selected = true;
                }

                if (!selected && dataSchvalovani.items[index].pravo_4) {
                    if ($("#Schvaleni_" + dataSchvalovani.items[index].id + "_4").prop("checked") !== !!dataSchvalovani.items[index].schvaleno_4) selected = true;
                }


                $("#poklk_row_" + dataSchvalovani.items[index].id).toggleClass("browserselectedrow", selected);
            };


            var schvaleniCheckboxClick = function () {
                var index = $(this).data("ronschvalenipoklk_index");
                if (index === undefined) return;

                oznacRadekPoklK(index);
            };
            var oznacVsechnyZaznamy = function (value, uroven) {
                for (var i = 0; i < dataSchvalovani.items.length; i++) {
                    var jePravo = false;
                    var checkboxId = null;

                    var originalValue = null;

                    switch (uroven) {
                        case '1' :
                            jePravo = dataSchvalovani.items[i].pravo_1;
                            checkboxId = 'Schvaleni_' + dataSchvalovani.items[i].id + '_1';
                            originalValue = dataSchvalovani.items[i].schvaleno_1;
                            break;

                        case '2' :
                            jePravo = dataSchvalovani.items[i].pravo_2;
                            checkboxId = 'Schvaleni_' + dataSchvalovani.items[i].id + '_2';
                            originalValue = dataSchvalovani.items[i].schvaleno_2;
                            break;

                        case '3' :
                            jePravo = dataSchvalovani.items[i].pravo_3;
                            checkboxId = 'Schvaleni_' + dataSchvalovani.items[i].id + '_3';
                            originalValue = dataSchvalovani.items[i].schvaleno_3;
                            break;

                        case '4' :
                            jePravo = dataSchvalovani.items[i].pravo_4;
                            checkboxId = 'Schvaleni_' + dataSchvalovani.items[i].id + '_4';
                            originalValue = dataSchvalovani.items[i].schvaleno_4;
                            break;
                    }

                    if (jePravo && checkboxId) {
                        var newvalue = !!( value < 0 ? originalValue : value);
                        if (document.getElementById(checkboxId).checked !== newvalue) {
                            document.getElementById(checkboxId).checked = newvalue;
                            oznacRadekPoklK(i);
                        }
                    }
                }
            };


            var schvaleniPoklKMenu = function ($sender, uroven) {
                var $menu = $("#schvaleniPoklKMenu");

                $menu
                    .off("click", "li")
                    .on("click", "li", function () {
                        oznacVsechnyZaznamy($(this).data("ron-hodnotaschvaleni"), uroven);
                    });

                ron.showPopupMenu($menu, {attachToElement: $sender});

                return false; // stop event propagation
            };


            $("#schvaleniPKMenu_1")
                .on("click", function () {
                    schvaleniPoklKMenu($(this), "1");
                    return false;
                });

            $("#schvaleniPKMenu_2")
                .on("click", function () {
                    schvaleniPoklKMenu($(this), "2");
                    return false;
                });

            $("#schvaleniPKMenu_3")
                .on("click", function () {
                    schvaleniPoklKMenu($(this), "3");
                    return false;
                });

            $("#schvaleniPKMenu_4")
                .on("click", function () {
                    schvaleniPoklKMenu($(this), "4");
                    return false;
                });

            $("#schvaleni_ALL_1")
                .on("click", function () {
                    oznacVsechnyZaznamy($(this).prop("checked"), "1");
                });

            $("#schvaleni_ALL_2")
                .on("click", function () {
                    oznacVsechnyZaznamy($(this).prop("checked"), "2");
                });

            $("#schvaleni_ALL_3")
                .on("click", function () {
                    oznacVsechnyZaznamy($(this).prop("checked"), "3");
                });

            $("#schvaleni_ALL_4")
                .on("click", function () {
                    oznacVsechnyZaznamy($(this).prop("checked"), "4");
                });

            $("#seznampokladniknihy")
                .on("click", "input", schvaleniCheckboxClick);

            $("#stornoHromadneSchvaleniPoklK")
                .on("click", function () {
                    window.location = $(this).data('browserlink');
                });

            $("#provestHromadneSchvaleniPoklK")
                .on("click", function () {
                    ron.showWorkingInfo();
                    this.form.submit();
                });


        }
    },

    formular : {
        init : function (dataTypyPolozek) {
            var typPolozky = $('#typ_polozky');

            var zobrazeniCastkyDleTypu = function (data) {
                var value = '';
                if (typeof data == 'object') {
                    value = $(this).val().toString();
                }
                else {
                    value = data;
                }
                for (var i = 0; i < dataTypyPolozek.items.length; i++) {
                    if (dataTypyPolozek.items[i].typ_polozky.toLowerCase() === value.toLowerCase()) {
                        $('#row_castka_bez_dph').toggle(dataTypyPolozek.items[i].povolit_castka_bez_dph === 1);
                        $('#row_castka_dph').toggle(dataTypyPolozek.items[i].povolit_castka_dph === 1);

                        $('#row_castka').toggle(dataTypyPolozek.items[i].povolit_castka === 1);
                        if (dataTypyPolozek.items[i].povolit_castka !== 1) {
                            $('#poklkniha_castka_noedit').removeClass('hidden');
                        } else {
                            $('#poklkniha_castka_noedit').addClass('hidden');
                        }
                    }
                }
            };

            var prepocetCastky = function () {
                var result;

                var $inputBezDPH = $('#row_castka_bez_dph').find('input');
                var $inputDPH = $('#row_castka_dph').find('input');

                result = ron.utils.stringToFloat($inputBezDPH.val()) + ron.utils.stringToFloat($inputDPH.val());
                $('#castka_pokladni_knihy').text(result);
                if ($inputBezDPH.length > 0 || $inputDPH.length > 0) {
                    $('#row_castka').find('input[name="castka"]').val(result);
                }
            };

            zobrazeniCastkyDleTypu($(typPolozky).find('select').val().toString());
            prepocetCastky();

            $(typPolozky).on('change','select', zobrazeniCastkyDleTypu);

            $('#row_castka_bez_dph').on('change', 'input', prepocetCastky);
            $('#row_castka_dph').on('change', 'input', prepocetCastky);
        }
    },

    detail : {
        vraceniZaznamuPokladniKnihyClick : function(sender) {
            $("#vracenipokladniknihy").show();
            $(this).hide();

            return false; // puvodni odkaz se nepouzije
        }
    }
};

$(function() {
    $(document.body)
        .on("click", ".vraceni_pokladni_knihy_link", ron.PokladniKniha.detail.vraceniZaznamuPokladniKnihyClick)
        .on('click', '#poklk_hromadneschvalovani', ron.PokladniKniha.hromadneSchvaleni.zobrazHromadne);
    if ($('#seznamtypu').length > 0) {
        ron.PokladniKniha.formular.init(JSON.parse($('#seznamtypu').val()));
    }
});
